summaryrefslogtreecommitdiffstats
path: root/kcachegrind/kcachegrind/tracedata.h
diff options
context:
space:
mode:
Diffstat (limited to 'kcachegrind/kcachegrind/tracedata.h')
-rw-r--r--kcachegrind/kcachegrind/tracedata.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kcachegrind/kcachegrind/tracedata.h b/kcachegrind/kcachegrind/tracedata.h
index edc4c8f8..cb97e623 100644
--- a/kcachegrind/kcachegrind/tracedata.h
+++ b/kcachegrind/kcachegrind/tracedata.h
@@ -1879,13 +1879,13 @@ class TraceData: public TraceCost
/**
* Search for item with given name and highest subcost of given cost type.
*
* For some items, they will only be found if the tqparent cost is given:
* Instr, Line, Call => need tqparent of type Function
* For Function, a tqparent of type Obj/File/Class can be given, but
* isn't needed.
*/
TraceCost* search(TraceItem::CostType, TQString,
- TraceCostType* ct = 0, TraceCost* tqparent = 0);
+ TraceCostType* ct = 0, TraceCost* parent = 0);
// for pretty function names without signature if unique...
TraceFunctionMap::Iterator functionIterator(TraceFunction*);
@@ -1879,13 +1879,13 @@ class TraceData: public TraceCost
* Search for item with given name and highest subcost of given cost type.
*
- * For some items, they will only be found if the tqparent cost is given:
- * Instr, Line, Call => need tqparent of type Function
- * For Function, a tqparent of type Obj/File/Class can be given, but
+ * For some items, they will only be found if the parent cost is given:
+ * Instr, Line, Call => need parent of type Function
+ * For Function, a parent of type Obj/File/Class can be given, but
* isn't needed.
*/